Introduction
============

The ``debops.ruby`` role can be used to configure a Ruby environment. The role
will install Ruby packages from the current OS release, as well as specified
Ruby gems, either system-wide or on a selected user account.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.0.0``. To install it, run::

    ansible-galaxy install debops.ruby

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
